@@ -4,6 +4,6 @@ def base64_to_file(content, filepath):
     fh.close()
 
 
-def round_to_n_decimal_places(self, value, n):
+def round_to_n_decimal_places(value, n):
     power = 10 ** n
     return float(int(value * power)) / power
